# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.user_memory_fact_get import UserMemoryFactGet  # noqa: E501

class TestUserMemoryFactGet(unittest.TestCase):
    """UserMemoryFactGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserMemoryFactGet:
        """Test UserMemoryFactGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserMemoryFactGet`
        """
        model = UserMemoryFactGet()  # noqa: E501
        if include_optional:
            return UserMemoryFactGet(
                access_count = 56,
                content = '',
                created_at = 56,
                fact_type = 'preference',
                id = 56,
                importance = 56,
                last_accessed_at = 56,
                source_chat_id = 56,
                valid_from = 56
            )
        else:
            return UserMemoryFactGet(
                access_count = 56,
                content = '',
                created_at = 56,
                fact_type = 'preference',
                id = 56,
                importance = 56,
                last_accessed_at = 56,
                valid_from = 56,
        )
        """

    def testUserMemoryFactGet(self):
        """Test UserMemoryFactGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
