# coding: utf-8

# flake8: noqa
"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from ai_assistant_server_connector.models.ai_assistant_reponse_stream_request import AIAssistantReponseStreamRequest
from ai_assistant_server_connector.models.ai_assistant_session_start import AIAssistantSessionStart
from ai_assistant_server_connector.models.ai_assistant_custom_skill_create import AiAssistantCustomSkillCreate
from ai_assistant_server_connector.models.ai_assistant_custom_skill_get import AiAssistantCustomSkillGet
from ai_assistant_server_connector.models.ai_assistant_custom_skill_patch import AiAssistantCustomSkillPatch
from ai_assistant_server_connector.models.ai_assistant_custom_skill_update import AiAssistantCustomSkillUpdate
from ai_assistant_server_connector.models.ai_assistant_get import AiAssistantGet
from ai_assistant_server_connector.models.ai_assistant_goal_create import AiAssistantGoalCreate
from ai_assistant_server_connector.models.ai_assistant_goal_create_update import AiAssistantGoalCreateUpdate
from ai_assistant_server_connector.models.ai_assistant_goal_get import AiAssistantGoalGet
from ai_assistant_server_connector.models.ai_assistant_lexicon_item import AiAssistantLexiconItem
from ai_assistant_server_connector.models.ai_assistant_lexicon_item_create_or_update import AiAssistantLexiconItemCreateOrUpdate
from ai_assistant_server_connector.models.ai_assistant_lexicon_item_new import AiAssistantLexiconItemNew
from ai_assistant_server_connector.models.ai_assistant_list_get import AiAssistantListGet
from ai_assistant_server_connector.models.ai_assistant_new import AiAssistantNew
from ai_assistant_server_connector.models.ai_assistant_setting_toggle import AiAssistantSettingToggle
from ai_assistant_server_connector.models.ai_assistant_setup_from_root import AiAssistantSetupFromRoot
from ai_assistant_server_connector.models.ai_assistant_skill_setting_get import AiAssistantSkillSettingGet
from ai_assistant_server_connector.models.ai_assistant_tool_setting_get import AiAssistantToolSettingGet
from ai_assistant_server_connector.models.ai_assistant_update import AiAssistantUpdate
from ai_assistant_server_connector.models.ai_assistant_usage_log_read import AiAssistantUsageLogRead
from ai_assistant_server_connector.models.ai_assistant_usage_logs_by_sessions_request import AiAssistantUsageLogsBySessionsRequest
from ai_assistant_server_connector.models.assistant_function import AssistantFunction
from ai_assistant_server_connector.models.assistant_type import AssistantType
from ai_assistant_server_connector.models.assistant_usage_type import AssistantUsageType
from ai_assistant_server_connector.models.avatar_option_get import AvatarOptionGet
from ai_assistant_server_connector.models.chat_history_chat_content import ChatHistoryChatContent
from ai_assistant_server_connector.models.chat_history_item import ChatHistoryItem
from ai_assistant_server_connector.models.chat_message_attachment import ChatMessageAttachment
from ai_assistant_server_connector.models.chat_message_attachment_type import ChatMessageAttachmentType
from ai_assistant_server_connector.models.chat_role import ChatRole
from ai_assistant_server_connector.models.collection_state import CollectionState
from ai_assistant_server_connector.models.collection_status import CollectionStatus
from ai_assistant_server_connector.models.conversation_style import ConversationStyle
from ai_assistant_server_connector.models.course_module_public import CourseModulePublic
from ai_assistant_server_connector.models.course_payment_type_str_enum import CoursePaymentTypeStrEnum
from ai_assistant_server_connector.models.course_public import CoursePublic
from ai_assistant_server_connector.models.emphemeral_credentials import EmphemeralCredentials
from ai_assistant_server_connector.models.fact_type import FactType
from ai_assistant_server_connector.models.goal_engagement_preset_get import GoalEngagementPresetGet
from ai_assistant_server_connector.models.goal_interactions_summary import GoalInteractionsSummary
from ai_assistant_server_connector.models.http_validation_error import HTTPValidationError
from ai_assistant_server_connector.models.interaction_type import InteractionType
from ai_assistant_server_connector.models.knowledgebase_state import KnowledgebaseState
from ai_assistant_server_connector.models.language_str_enum import LanguageStrEnum
from ai_assistant_server_connector.models.location_inner import LocationInner
from ai_assistant_server_connector.models.memory_fact_forget_request import MemoryFactForgetRequest
from ai_assistant_server_connector.models.memory_fact_record_request import MemoryFactRecordRequest
from ai_assistant_server_connector.models.memory_ingest_request import MemoryIngestRequest
from ai_assistant_server_connector.models.module_lesson_public import ModuleLessonPublic
from ai_assistant_server_connector.models.portal_ai_info_get import PortalAiInfoGet
from ai_assistant_server_connector.models.portal_ai_info_update import PortalAiInfoUpdate
from ai_assistant_server_connector.models.portal_info_request import PortalInfoRequest
from ai_assistant_server_connector.models.portal_owner_info import PortalOwnerInfo
from ai_assistant_server_connector.models.rag_query_response import RagQueryResponse
from ai_assistant_server_connector.models.response_chunk import ResponseChunk
from ai_assistant_server_connector.models.response_chunk_type import ResponseChunkType
from ai_assistant_server_connector.models.response_wrapper import ResponseWrapper
from ai_assistant_server_connector.models.response_wrapper_ai_assistant_session_start import ResponseWrapperAIAssistantSessionStart
from ai_assistant_server_connector.models.response_wrapper_ai_assistant_get import ResponseWrapperAiAssistantGet
from ai_assistant_server_connector.models.response_wrapper_bool import ResponseWrapperBool
from ai_assistant_server_connector.models.response_wrapper_int import ResponseWrapperInt
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_custom_skill_get import ResponseWrapperListAiAssistantCustomSkillGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_goal_get import ResponseWrapperListAiAssistantGoalGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_list_get import ResponseWrapperListAiAssistantListGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_skill_setting_get import ResponseWrapperListAiAssistantSkillSettingGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_tool_setting_get import ResponseWrapperListAiAssistantToolSettingGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_usage_log_read import ResponseWrapperListAiAssistantUsageLogRead
from ai_assistant_server_connector.models.response_wrapper_list_avatar_option_get import ResponseWrapperListAvatarOptionGet
from ai_assistant_server_connector.models.response_wrapper_list_goal_engagement_preset_get import ResponseWrapperListGoalEngagementPresetGet
from ai_assistant_server_connector.models.response_wrapper_list_user_memory_fact_get import ResponseWrapperListUserMemoryFactGet
from ai_assistant_server_connector.models.response_wrapper_list_voice_option_get import ResponseWrapperListVoiceOptionGet
from ai_assistant_server_connector.models.response_wrapper_portal_ai_info_get import ResponseWrapperPortalAiInfoGet
from ai_assistant_server_connector.models.response_wrapper_rag_query_response import ResponseWrapperRagQueryResponse
from ai_assistant_server_connector.models.response_wrapper_user_memory_profile_get import ResponseWrapperUserMemoryProfileGet
from ai_assistant_server_connector.models.result import Result
from ai_assistant_server_connector.models.score import Score
from ai_assistant_server_connector.models.search_result import SearchResult
from ai_assistant_server_connector.models.usage_details import UsageDetails
from ai_assistant_server_connector.models.user_goal_interaction_create import UserGoalInteractionCreate
from ai_assistant_server_connector.models.user_memory_fact_get import UserMemoryFactGet
from ai_assistant_server_connector.models.user_memory_profile_get import UserMemoryProfileGet
from ai_assistant_server_connector.models.validation_error import ValidationError
from ai_assistant_server_connector.models.voice_option_get import VoiceOptionGet
