# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr

class MemoryIngestRequest(BaseModel):
    """
    Payload posted by agent_repo at run finalization.  # noqa: E501
    """
    assistant_message: StrictStr = Field(...)
    chat_id: StrictInt = Field(...)
    portal_member_id: StrictInt = Field(...)
    run_id: StrictStr = Field(...)
    user_message: StrictStr = Field(...)
    __properties = ["assistant_message", "chat_id", "portal_member_id", "run_id", "user_message"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MemoryIngestRequest:
        """Create an instance of MemoryIngestRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MemoryIngestRequest:
        """Create an instance of MemoryIngestRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return MemoryIngestRequest.parse_obj(obj)

        _obj = MemoryIngestRequest.parse_obj({
            "assistant_message": obj.get("assistant_message"),
            "chat_id": obj.get("chat_id"),
            "portal_member_id": obj.get("portal_member_id"),
            "run_id": obj.get("run_id"),
            "user_message": obj.get("user_message")
        })
        return _obj


