# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.ai_assistant_usage_log_read import AiAssistantUsageLogRead  # noqa: E501

class TestAiAssistantUsageLogRead(unittest.TestCase):
    """AiAssistantUsageLogRead unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiAssistantUsageLogRead:
        """Test AiAssistantUsageLogRead
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiAssistantUsageLogRead`
        """
        model = AiAssistantUsageLogRead()  # noqa: E501
        if include_optional:
            return AiAssistantUsageLogRead(
                ai_assistant_id = 56,
                commited_at = 56,
                created_at = 56,
                id = 56,
                incoming_tokens = 56,
                model = '',
                outgoing_tokens = 56,
                portal_member_id = 56,
                price_incoming = 1.337,
                price_outgoing = 1.337,
                price_usd = 1.337,
                session_id = '',
                usage_type = 'text'
            )
        else:
            return AiAssistantUsageLogRead(
                ai_assistant_id = 56,
                created_at = 56,
                id = 56,
                model = '',
                portal_member_id = 56,
                session_id = '',
                usage_type = 'text',
        )
        """

    def testAiAssistantUsageLogRead(self):
        """Test AiAssistantUsageLogRead"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
