# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from ai_assistant_server_connector.models.chat_history_item import ChatHistoryItem
from ai_assistant_server_connector.models.chat_message_attachment import ChatMessageAttachment
from ai_assistant_server_connector.models.portal_info_request import PortalInfoRequest

class AIAssistantReponseStreamRequest(BaseModel):
    """
    AIAssistantReponseStreamRequest
    """
    assistant_chat_member_id: StrictInt = Field(...)
    attachments: Optional[conlist(ChatMessageAttachment)] = None
    chat_id: StrictInt = Field(...)
    chat_session_id: StrictInt = Field(...)
    history: conlist(ChatHistoryItem) = Field(...)
    name_chat: Optional[StrictBool] = False
    portal_info: Optional[PortalInfoRequest] = None
    session_id: StrictStr = Field(...)
    user_prompt: StrictStr = Field(...)
    __properties = ["assistant_chat_member_id", "attachments", "chat_id", "chat_session_id", "history", "name_chat", "portal_info", "session_id", "user_prompt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AIAssistantReponseStreamRequest:
        """Create an instance of AIAssistantReponseStreamRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item in self.attachments:
                if _item:
                    _items.append(_item.to_dict())
            _dict['attachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in history (list)
        _items = []
        if self.history:
            for _item in self.history:
                if _item:
                    _items.append(_item.to_dict())
            _dict['history'] = _items
        # override the default output from pydantic by calling `to_dict()` of portal_info
        if self.portal_info:
            _dict['portal_info'] = self.portal_info.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AIAssistantReponseStreamRequest:
        """Create an instance of AIAssistantReponseStreamRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AIAssistantReponseStreamRequest.parse_obj(obj)

        _obj = AIAssistantReponseStreamRequest.parse_obj({
            "assistant_chat_member_id": obj.get("assistant_chat_member_id"),
            "attachments": [ChatMessageAttachment.from_dict(_item) for _item in obj.get("attachments")] if obj.get("attachments") is not None else None,
            "chat_id": obj.get("chat_id"),
            "chat_session_id": obj.get("chat_session_id"),
            "history": [ChatHistoryItem.from_dict(_item) for _item in obj.get("history")] if obj.get("history") is not None else None,
            "name_chat": obj.get("name_chat") if obj.get("name_chat") is not None else False,
            "portal_info": PortalInfoRequest.from_dict(obj.get("portal_info")) if obj.get("portal_info") is not None else None,
            "session_id": obj.get("session_id"),
            "user_prompt": obj.get("user_prompt")
        })
        return _obj


