# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class PortalAiInfoGet(BaseModel):
    """
    PortalAiInfoGet
    """
    academy_info: Optional[StrictStr] = None
    agent_name: Optional[StrictStr] = None
    agent_personality: Optional[StrictStr] = None
    created_at: StrictInt = Field(...)
    goal: Optional[StrictStr] = None
    last_updated_at: StrictInt = Field(...)
    portal_id: StrictInt = Field(...)
    portal_owner_info: Optional[StrictStr] = None
    __properties = ["academy_info", "agent_name", "agent_personality", "created_at", "goal", "last_updated_at", "portal_id", "portal_owner_info"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PortalAiInfoGet:
        """Create an instance of PortalAiInfoGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PortalAiInfoGet:
        """Create an instance of PortalAiInfoGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PortalAiInfoGet.parse_obj(obj)

        _obj = PortalAiInfoGet.parse_obj({
            "academy_info": obj.get("academy_info"),
            "agent_name": obj.get("agent_name"),
            "agent_personality": obj.get("agent_personality"),
            "created_at": obj.get("created_at"),
            "goal": obj.get("goal"),
            "last_updated_at": obj.get("last_updated_at"),
            "portal_id": obj.get("portal_id"),
            "portal_owner_info": obj.get("portal_owner_info")
        })
        return _obj


