# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ai_assistant_server_connector.api.memory_api import MemoryApi  # noqa: E501


class TestMemoryApi(unittest.IsolatedAsyncioTestCase):
    """MemoryApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = MemoryApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_ai_assistant_api_clear_all_facts(self) -> None:
        """Test case for ai_assistant_api_clear_all_facts

        Clear All Facts  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_clear_profile(self) -> None:
        """Test case for ai_assistant_api_clear_profile

        Clear Profile  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_count_facts(self) -> None:
        """Test case for ai_assistant_api_count_facts

        Count Facts  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_delete_fact(self) -> None:
        """Test case for ai_assistant_api_delete_fact

        Delete Fact  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_delete_profile_key(self) -> None:
        """Test case for ai_assistant_api_delete_profile_key

        Delete Profile Key  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_get_profile(self) -> None:
        """Test case for ai_assistant_api_get_profile

        Get Profile  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_list_facts(self) -> None:
        """Test case for ai_assistant_api_list_facts

        List Facts  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_memory_forget_facts(self) -> None:
        """Test case for ai_assistant_api_memory_forget_facts

        Memory Forget Facts  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_memory_ingest(self) -> None:
        """Test case for ai_assistant_api_memory_ingest

        Memory Ingest  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_memory_record_fact(self) -> None:
        """Test case for ai_assistant_api_memory_record_fact

        Memory Record Fact  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
