# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from ai_assistant_server_connector.models.assistant_usage_type import AssistantUsageType

class AiAssistantUsageLogRead(BaseModel):
    """
    AiAssistantUsageLogRead
    """
    ai_assistant_id: StrictInt = Field(...)
    commited_at: Optional[StrictInt] = None
    created_at: StrictInt = Field(...)
    id: StrictInt = Field(...)
    incoming_tokens: Optional[StrictInt] = None
    model: StrictStr = Field(...)
    outgoing_tokens: Optional[StrictInt] = None
    portal_member_id: StrictInt = Field(...)
    price_incoming: Optional[Union[StrictFloat, StrictInt]] = None
    price_outgoing: Optional[Union[StrictFloat, StrictInt]] = None
    price_usd: Optional[Union[StrictFloat, StrictInt]] = None
    session_id: StrictStr = Field(...)
    usage_type: AssistantUsageType = Field(...)
    __properties = ["ai_assistant_id", "commited_at", "created_at", "id", "incoming_tokens", "model", "outgoing_tokens", "portal_member_id", "price_incoming", "price_outgoing", "price_usd", "session_id", "usage_type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AiAssistantUsageLogRead:
        """Create an instance of AiAssistantUsageLogRead from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AiAssistantUsageLogRead:
        """Create an instance of AiAssistantUsageLogRead from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AiAssistantUsageLogRead.parse_obj(obj)

        _obj = AiAssistantUsageLogRead.parse_obj({
            "ai_assistant_id": obj.get("ai_assistant_id"),
            "commited_at": obj.get("commited_at"),
            "created_at": obj.get("created_at"),
            "id": obj.get("id"),
            "incoming_tokens": obj.get("incoming_tokens"),
            "model": obj.get("model"),
            "outgoing_tokens": obj.get("outgoing_tokens"),
            "portal_member_id": obj.get("portal_member_id"),
            "price_incoming": obj.get("price_incoming"),
            "price_outgoing": obj.get("price_outgoing"),
            "price_usd": obj.get("price_usd"),
            "session_id": obj.get("session_id"),
            "usage_type": obj.get("usage_type")
        })
        return _obj


