# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictInt

class GoalInteractionsSummary(BaseModel):
    """
    GoalInteractionsSummary
    """
    is_available: Optional[StrictBool] = True
    last_engagement_at: Optional[StrictInt] = None
    last_opt_out_at: Optional[StrictInt] = None
    recent_interaction_count: Optional[StrictInt] = 0
    total_interaction_count: Optional[StrictInt] = 0
    __properties = ["is_available", "last_engagement_at", "last_opt_out_at", "recent_interaction_count", "total_interaction_count"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GoalInteractionsSummary:
        """Create an instance of GoalInteractionsSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GoalInteractionsSummary:
        """Create an instance of GoalInteractionsSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GoalInteractionsSummary.parse_obj(obj)

        _obj = GoalInteractionsSummary.parse_obj({
            "is_available": obj.get("is_available") if obj.get("is_available") is not None else True,
            "last_engagement_at": obj.get("last_engagement_at"),
            "last_opt_out_at": obj.get("last_opt_out_at"),
            "recent_interaction_count": obj.get("recent_interaction_count") if obj.get("recent_interaction_count") is not None else 0,
            "total_interaction_count": obj.get("total_interaction_count") if obj.get("total_interaction_count") is not None else 0
        })
        return _obj


