# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ai_assistant_server_connector.api.assistants_api import AssistantsApi  # noqa: E501


class TestAssistantsApi(unittest.IsolatedAsyncioTestCase):
    """AssistantsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = AssistantsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_ai_assistant_api_assistant_add(self) -> None:
        """Test case for ai_assistant_api_assistant_add

        Assistant Add  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_delete(self) -> None:
        """Test case for ai_assistant_api_assistant_delete

        Assistant Delete  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_get(self) -> None:
        """Test case for ai_assistant_api_assistant_get

        Assistant Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_landing_primary_get(self) -> None:
        """Test case for ai_assistant_api_assistant_landing_primary_get

        Assistant Landing Primary Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_landing_primary_update(self) -> None:
        """Test case for ai_assistant_api_assistant_landing_primary_update

        Assistant Landing Primary Update  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_primary_get(self) -> None:
        """Test case for ai_assistant_api_assistant_primary_get

        Assistant Primary Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_primary_goals_engagement_add(self) -> None:
        """Test case for ai_assistant_api_assistant_primary_goals_engagement_add

        Assistant Primary Goals Engagement Add  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_primary_goals_get(self) -> None:
        """Test case for ai_assistant_api_assistant_primary_goals_get

        Assistant Primary Goals Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_primary_update(self) -> None:
        """Test case for ai_assistant_api_assistant_primary_update

        Assistant Primary Update  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_response_stream(self) -> None:
        """Test case for ai_assistant_api_assistant_response_stream

        Assistant Response Stream  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_run_cancel(self) -> None:
        """Test case for ai_assistant_api_assistant_run_cancel

        Assistant Run Cancel  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_session_start(self) -> None:
        """Test case for ai_assistant_api_assistant_session_start

        Assistant Session Start  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_shared_primary_get(self) -> None:
        """Test case for ai_assistant_api_assistant_shared_primary_get

        Assistant Shared Primary Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_shared_primary_update(self) -> None:
        """Test case for ai_assistant_api_assistant_shared_primary_update

        Assistant Shared Primary Update  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assistant_update(self) -> None:
        """Test case for ai_assistant_api_assistant_update

        Assistant Update  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_assitants_list(self) -> None:
        """Test case for ai_assistant_api_assitants_list

        Assitants List  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_custom_skill_create(self) -> None:
        """Test case for ai_assistant_api_shared_primary_custom_skill_create

        Shared Primary Custom Skill Create  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_custom_skill_delete(self) -> None:
        """Test case for ai_assistant_api_shared_primary_custom_skill_delete

        Shared Primary Custom Skill Delete  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_custom_skill_patch(self) -> None:
        """Test case for ai_assistant_api_shared_primary_custom_skill_patch

        Shared Primary Custom Skill Patch  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_custom_skill_update(self) -> None:
        """Test case for ai_assistant_api_shared_primary_custom_skill_update

        Shared Primary Custom Skill Update  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_custom_skills_get(self) -> None:
        """Test case for ai_assistant_api_shared_primary_custom_skills_get

        Shared Primary Custom Skills Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_skill_settings_get(self) -> None:
        """Test case for ai_assistant_api_shared_primary_skill_settings_get

        Shared Primary Skill Settings Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_skill_toggle(self) -> None:
        """Test case for ai_assistant_api_shared_primary_skill_toggle

        Shared Primary Skill Toggle  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_tool_settings_get(self) -> None:
        """Test case for ai_assistant_api_shared_primary_tool_settings_get

        Shared Primary Tool Settings Get  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_shared_primary_tool_toggle(self) -> None:
        """Test case for ai_assistant_api_shared_primary_tool_toggle

        Shared Primary Tool Toggle  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
